:orphan:

.. |nark| replace:: ``nark``
.. _nark: https://github.com/hotoffthehamster/nark

.. |hamster-lib| replace:: ``hamster-lib``
.. _hamster-lib: https://github.com/projecthamster/hamster-lib

.. |legacy-hamster| replace:: Legacy Hamster
.. _legacy-hamster: https://github.com/projecthamster/hamster

=======================================================================================
|legacy-hamster|_ Authors [from before |hamster-lib|_ was built and |nark|_ was forked]
=======================================================================================

The `original Hamster project <https://github.com/projecthamster/hamster/>`_
was the inspiration for |hamster-lib|_ and |nark|_, but it's its own codebase.

*(This list is maintained only for posterity; none of these authors' code appears
in either hamster-lib or nark.)*

Head Hamsters
-------------

* Toms Bauģis
* Patryk Zawadzki

Hamster Horde
-------------

.. HINT: Generate a list of Authors from the git log:
..
..   git log --format="%an" | sort -u

* Abduxukur Abdurixit
* Adi Roiban
* Adrian Guniš
* Aleksander T. Bradtke
* Alexander Nyakhaychyk
* Alexander Shopov
* Alexandre Prokoudine
* Alex Hayes
* Ali Akbar Najafian
* Amanpreet Singh Alam
* Amitakhya Phukan
* Andika Triwidada
* Andreas Köhler
* Andrej Žnidaršič
* Ani
* Anita Reitere
* Ankur Sinha
* Antonio Fernandes C. Neto
* Antón Méixome
* Aputsiaq Janussen
* Aron Xu
* A S Alam
* Ashton Kemerling
* Ask H. Larsen
* Aurimas Černius
* Baris Cicek
* Branko Kokanović
* Brice Burgess
* Bruce Cowan
* Bruno Brouard
* Carles Ferrando
* Changwoo Ryu
* Chao-Hsiung Liao
* Cheng-Chia Tseng
* Chris lutje Spelberg
* Christian Kirbach
* Christian Rose
* Claude Paroz
* Clytie Siddall
* Colin Walters
* Damyan Ivanov
* Daniel Korostil
* Daniel Mustieles
* Daniel Nylander
* Daniel S. Koda
* Dirgita
* Djavan Fagundes
* Djihed Afifi
* Dr. T. Vasudevan / drtvasudevan / drtv
* Duarte Loreto
* Dumitru Mișu Moldovan
* dumol
* Dylan McCall
* Enrico Nicoletto
* Erdal Ronahi
* Eric Goller / elbenfreund
* Fábio Nogueira
* Felix I / ifelix
* foser
* Francisco Diéguez
* Fran Diéguez
* Frédéric Péters
* Funda Wang
* Gabor Karsay
* Gabor Keleman / Kelemen
* George Stefanakis
* Gheyret T.Kenji
* Gil Forcada (Codinachs)
* Gintautas Miliauskas
* Giorgos Logiotatidis
* Gopala Krishna Koduri
* Goran Rakic
* Grzegorz Rynkowski
* Hendrik Richter
* Hideki Yamane
* Ignacio Casal Quinteiro
* Ihar Hrachyshka
* Ilkka Tuohela
* immerrr
* Inaki Larrañaga Murgoitio
* Isis Binder
* Ivar Smolin
* Izidor Matušov
* James Westby
* Jamil Ahmed
* Jan-Carel Brand
* Javier Jardón
* JC Brand
* Jean-Philippe Fleury
* jerome.lacoste
* Jesse Johnson
* \J. Félix Ontañón
* Jiro Matsuzawa
* Joe Hansen
* Jonathan Brett
* Jordi Serratosa
* Jorge González
* Jovan Naumovski
* Juanje Ojeda Croissier
* Kasia Bondarava
* Kenneth Nielsen
* Kevin_Wei_2
* Khaled Hosny
* Kirill Roskolii
* Kjartan Maraas
* Kostas Papadimas
* Krishnababu Krothapalli
* Kris Thomsen
* Laurent Dhima
* Leonardo Ferreira Fontenelle
* Leonid Kanter
* Luca Ferretti
* Lucian Adrian Grijincu
* Lu Gan
* Lukas Lommer
* Łukasz Jernaś
* Maciek Chudek
* Manoj Kumar Giri
* Marek Černocký
* Mario Blättermann
* Marios Zindilis
* Markus Koller
* Martin -nexus- Filip
* Matej Urban (Urbančič)
* Matías Ribecky
* Mattias Põldaru
* Maxim Ermilov
* Maxim V. Dziumanenko
* Media Modifications, Ltd.
* Michael Kotsarinis
* Michal Bojanowski
* Milo Casagrande
* Miloš Popović
* Miquel Esplà
* Mjumbe Wawatu Ukweli
* msize
* Muhammet Kara
* Nathan Samson
* Nickolay V. Shmyrev
* Nicolas Chachereau
* Nikos Charonitakis
* Nilamdyuti Goswami
* Nishio Futoshi
* Og B. Maciel
* OKANO Takayoshi
* Olav Vitters
* Pēteris Caune
* Petr Kovar
* Phil Bull
* Philipp Kerling
* Philip Withnall
* Pieter Frenssen
* Piotr Drąg
* Praveen Arimbrathodiyil
* Praveen Illa
* Priit Laes
* Profpatsch
* Przemysław Wesołek
* Rajesh Ranjan
* Ray Wang
* Rex Tsai
* Ricky Burgin
* Rodolphe Pelloux-Prayer
* Rodrigo L. M. Flores
* Rolf Kleef
* Rudolfs Mazurs
* Runa Bhattacharjee
* Sandeep Shedmake
* Sandra Marakkala Danishka Navin
* Sebastian Leidig
* Sergey Tereschenko
* Shankar Prasad
* sietse
* Sílvia Miranda
* Simos Xenitellis
* Sweta Kothari
* Takayoshi Okano
* Takayuki Kusano
* Takeshi Aihana
* Ted Smith
* Teliute / TeliuTe
* Theppitak Karoonboonyanan
* Thomas Hindoe Paaboel Andersen
* Thomas Ruoff
* Thomas Thurman
* Tiffany Antopolski
* Timo Jyrinki
* Tomas Babej
* Tomasz Dominikowski
* Tommi Vainikainen
* Tom Tryfonidis
* vasudeven
* Vladimir Melo
* weitao
* Wolfgang Stöggl
* Wouter Bolsterlee
* Yair Hershkovitz
* Yaron Shahrabani
* Yinghua Wang
* YunQiang Su
* Yuri Myasoedov
* Žygimantas Beručka
* Мирослав Николић

